@@ -13,9 +13,14 @@
 # limitations under the License.
 
 """Unit test for repo_logging module."""
+
+import contextlib
+import io
+import logging
 import unittest
 from unittest import mock
 
+from color import SetDefaultColoring
 from error import RepoExitError
 from repo_logging import RepoLogger
 
@@ -62,3 +67,35 @@ class TestRepoLogger(unittest.TestCase):
                 mock.call("Repo command failed: %s", "RepoExitError"),
             ]
         )
+
+    def test_log_with_format_string(self):
+        """Test different log levels with format strings."""
+
+        # Set color output to "always" for consistent test results.
+        # This ensures the logger's behavior is uniform across different
+        # environments and git configurations.
+        SetDefaultColoring("always")
+
+        # Regex pattern to match optional ANSI color codes.
+        # \033    - Escape character
+        # \[      - Opening square bracket
+        # [0-9;]* - Zero or more digits or semicolons
+        # m       - Ending 'm' character
+        # ?       - Makes the entire group optional
+        opt_color = r"(\033\[[0-9;]*m)?"
+
+        for level in (logging.INFO, logging.WARN, logging.ERROR):
+            name = logging.getLevelName(level)
+
+            with self.subTest(level=level, name=name):
+                output = io.StringIO()
+
+                with contextlib.redirect_stderr(output):
+                    logger = RepoLogger(__name__)
+                    logger.log(level, "%s", "100% pass")
+
+                self.assertRegex(
+                    output.getvalue().strip(),
+                    f"^{opt_color}100% pass{opt_color}$",
+                    f"failed for level {name}",
+                )
